@@ -18,6 +18,7 @@ API application handler for Barbican
 """
 import os
 
+from paste import deploy
 import pecan
 
 try:
@@ -31,7 +32,6 @@ from oslo_log import log
 from barbican.api.controllers import versions
 from barbican.api import hooks
 from barbican.common import config
-from barbican import i18n as u
 from barbican.model import repositories
 from barbican import queue
 
@@ -87,7 +87,7 @@ def main_app(func):
         if newrelic_loaded:
             wsgi_app = newrelic.agent.WSGIApplicationWrapper(wsgi_app)
         LOG = log.getLogger(__name__)
-        LOG.info(u._LI('Barbican app created and initialized'))
+        LOG.info('Barbican app created and initialized')
         return wsgi_app
     return _wrapper
 
@@ -102,3 +102,9 @@ def create_main_app(global_config, **local_conf):
 def create_version_app(global_config, **local_conf):
     wsgi_app = pecan.make_app(versions.VersionsController())
     return wsgi_app
+
+
+def get_api_wsgi_script():
+    conf = '/etc/barbican/barbican-api-paste.ini'
+    application = deploy.loadapp('config:%s' % conf)
+    return application
