@@ -62,7 +62,7 @@ class BaseVersionController(object):
                 }, {
                     'rel': 'describedby',
                     'type': 'text/html',
-                    'href': 'http://docs.openstack.org/'
+                    'href': 'https://docs.openstack.org/'
                 }
             ],
             'media-types': [
