@@ -21,11 +21,14 @@ quite intense for sqlalchemy, and maybe could be simplified.
 """
 
 import logging
+import re
 import sys
 import time
-import uuid
 
+from oslo_db import exception as db_exc
+from oslo_db.sqlalchemy import session
 from oslo_utils import timeutils
+from oslo_utils import uuidutils
 import sqlalchemy
 from sqlalchemy import func as sa_func
 from sqlalchemy import or_
@@ -92,7 +95,7 @@ def hard_reset():
 def setup_database_engine_and_factory():
     global sa_logger, _SESSION_FACTORY, _ENGINE
 
-    LOG.info(u._LI('Setting up database engine and session factory'))
+    LOG.info('Setting up database engine and session factory')
     if CONF.debug:
         sa_logger = logging.getLogger('sqlalchemy.engine')
         sa_logger.setLevel(logging.DEBUG)
@@ -169,14 +172,9 @@ def _get_engine(engine):
     # connection_dict = sqlalchemy.engine.url.make_url(_CONNECTION)
 
         engine_args = {
-            'pool_recycle': CONF.sql_idle_timeout,
-            'echo': False,
-            'convert_unicode': True}
-        if CONF.sql_pool_class:
-            engine_args['poolclass'] = utils.get_class_for(
-                'sqlalchemy.pool', CONF.sql_pool_class)
+            'idle_timeout': CONF.sql_idle_timeout}
         if CONF.sql_pool_size:
-            engine_args['pool_size'] = CONF.sql_pool_size
+            engine_args['max_pool_size'] = CONF.sql_pool_size
         if CONF.sql_pool_max_overflow:
             engine_args['max_overflow'] = CONF.sql_pool_max_overflow
 
@@ -200,7 +198,7 @@ def _get_engine(engine):
 
             _auto_generate_tables(engine, tables)
         else:
-            LOG.info(u._LI('Not auto-creating barbican registry DB'))
+            LOG.info('Not auto-creating barbican registry DB')
 
     return engine
 
@@ -232,7 +230,7 @@ def _create_engine(connection, **engine_args):
     LOG.debug('Sql connection: please check "sql_connection" property in '
               'barbican configuration file; Args: %s', engine_args)
 
-    engine = sqlalchemy.create_engine(connection, **engine_args)
+    engine = session.create_engine(connection, **engine_args)
 
     # TODO(jfwood): if 'mysql' in connection_dict.drivername:
     # TODO(jfwood): sqlalchemy.event.listen(_ENGINE, 'checkout',
@@ -247,11 +245,11 @@ def _create_engine(connection, **engine_args):
 def _auto_generate_tables(engine, tables):
     if tables and 'alembic_version' in tables:
         # Upgrade the database to the latest version.
-        LOG.info(u._LI('Updating schema to latest version'))
+        LOG.info('Updating schema to latest version')
         commands.upgrade()
     else:
         # Create database tables from our models.
-        LOG.info(u._LI('Auto-creating barbican registry DB'))
+        LOG.info('Auto-creating barbican registry DB')
         models.BASE.metadata.create_all(engine)
 
         # Sync the alembic version 'head' with current models.
@@ -269,7 +267,7 @@ def wrap_db_error(f):
 
             remaining_attempts = CONF.sql_max_retries
             while True:
-                LOG.warning(u._LW('SQL connection failed. %d attempts left.'),
+                LOG.warning('SQL connection failed. %d attempts left.',
                             remaining_attempts)
                 remaining_attempts -= 1
                 time.sleep(CONF.sql_retry_interval)
@@ -373,7 +371,7 @@ class BaseRepo(object):
             entity = query.one()
 
         except sa_orm.exc.NoResultFound:
-            LOG.exception(u._LE("Not found for %s"), entity_id)
+            LOG.exception("Not found for %s", entity_id)
             entity = None
             if not suppress_exception:
                 _raise_entity_not_found(self._do_entity_name(), entity_id)
@@ -407,9 +405,10 @@ class BaseRepo(object):
         try:
             LOG.debug("Saving entity...")
             entity.save(session=session)
-        except sqlalchemy.exc.IntegrityError:
-            LOG.exception(u._LE('Problem saving entity for create'))
-            _raise_entity_already_exists(self._do_entity_name())
+        except db_exc.DBDuplicateEntry as e:
+            LOG.exception('Problem saving entity for create')
+            error_msg = re.sub('[()]', '', str(e.args))
+            raise exception.ConstraintCheck(error=error_msg)
 
         LOG.debug('Elapsed repo '
                   'create secret:%s', (time.time() - start))  # DEBUG
@@ -559,8 +558,7 @@ class BaseRepo(object):
                 # Its a soft delete so its more like entity update
                 entity.delete(session=session)
         except sqlalchemy.exc.SQLAlchemyError:
-            LOG.exception(u._LE('Problem finding project related entity to '
-                                'delete'))
+            LOG.exception('Problem finding project related entity to delete')
             if not suppress_exception:
                 raise exception.BarbicanException(u._('Error deleting project '
                                                       'entities for '
@@ -596,7 +594,7 @@ class ProjectRepo(BaseRepo):
         except sa_orm.exc.NoResultFound:
             entity = None
             if not suppress_exception:
-                LOG.exception(u._LE("Problem getting Project %s"),
+                LOG.exception("Problem getting Project %s",
                               external_project_id)
                 raise exception.NotFound(u._(
                     "No {entity_name} found with keystone-ID {id}").format(
@@ -799,7 +797,7 @@ class SecretRepo(BaseRepo):
         except sa_orm.exc.NoResultFound:
             entity = None
             if not suppress_exception:
-                LOG.exception(u._LE("Problem getting secret %s"),
+                LOG.exception("Problem getting secret %s",
                               entity_id)
                 raise exception.NotFound(u._(
                     "No secret found with secret-ID {id}").format(
@@ -981,7 +979,7 @@ class KEKDatumRepo(BaseRepo):
             kek_datum = models.KEKDatum()
 
             kek_datum.kek_label = "project-{0}-key-{1}".format(
-                project.external_id, uuid.uuid4())
+                project.external_id, uuidutils.generate_uuid())
             kek_datum.project_id = project.id
             kek_datum.plugin_name = plugin_name
             kek_datum.status = models.States.ACTIVE
@@ -1339,8 +1337,7 @@ class ContainerRepo(BaseRepo):
         except sa_orm.exc.NoResultFound:
             entity = None
             if not suppress_exception:
-                LOG.exception(u._LE("Problem getting container %s"),
-                              entity_id)
+                LOG.exception("Problem getting container %s", entity_id)
                 raise exception.NotFound(u._(
                     "No container found with container-ID {id}").format(
                         entity_name=self._do_entity_name(),
@@ -1430,7 +1427,7 @@ class ContainerConsumerRepo(BaseRepo):
             container.updated_at = timeutils.utcnow()
             container.consumers.append(new_consumer)
             container.save(session=session)
-        except sqlalchemy.exc.IntegrityError:
+        except db_exc.DBDuplicateEntry:
             session.rollback()  # We know consumer already exists.
 
             # This operation is idempotent, so log this and move on
@@ -2276,7 +2273,7 @@ class ProjectSecretStoreRepo(BaseRepo):
         try:
             entity = query.one()
         except sa_orm.exc.NoResultFound:
-            LOG.info(u._LE("No preferred secret store found for project = %s"),
+            LOG.info("No preferred secret store found for project = %s",
                      project_id)
             entity = None
             if not suppress_exception:
@@ -2512,9 +2509,3 @@ def _raise_no_entities_found(entity_name):
     raise exception.NotFound(
         u._("No entities of type {entity_name} found").format(
             entity_name=entity_name))
-
-
-def _raise_entity_already_exists(entity_name):
-    raise exception.Duplicate(
-        u._("Entity '{entity_name}' "
-            "already exists").format(entity_name=entity_name))
