@@ -17,11 +17,10 @@ import base64
 import copy
 import datetime
 import os
-import uuid
+from oslo_utils import uuidutils
 
 from Crypto.PublicKey import RSA
 from Crypto.Util import asn1
-from oslo_config import cfg
 import pki
 
 subcas_available = True
@@ -39,48 +38,21 @@ import pki.kra
 import pki.profile
 from requests import exceptions as request_exceptions
 
-from barbican.common import config
 from barbican.common import exception
 from barbican.common import utils
 from barbican import i18n as u
+
+# we want to keep the dogtag config options separated. That way we
+# do not need to import every dogtag requirement to generate the
+# sample config
+import barbican.plugin.dogtag_config_opts  # noqa
 import barbican.plugin.interface.certificate_manager as cm
 import barbican.plugin.interface.secret_store as sstore
 
-CONF = config.new_config()
+# reuse the conf object to not call config.new_config() twice
+CONF = barbican.plugin.dogtag_config_opts.CONF
 LOG = utils.getLogger(__name__)
 
-dogtag_plugin_group = cfg.OptGroup(name='dogtag_plugin',
-                                   title="Dogtag Plugin Options")
-dogtag_plugin_opts = [
-    cfg.StrOpt('pem_path',
-               help=u._('Path to PEM file for authentication')),
-    cfg.StrOpt('dogtag_host',
-               default="localhost",
-               help=u._('Hostname for the Dogtag instance')),
-    cfg.StrOpt('dogtag_port',
-               default="8443",
-               help=u._('Port for the Dogtag instance')),
-    cfg.StrOpt('nss_db_path',
-               help=u._('Path to the NSS certificate database')),
-    cfg.StrOpt('nss_password',
-               help=u._('Password for the NSS certificate databases'),
-               secret=True),
-    cfg.StrOpt('simple_cmc_profile',
-               help=u._('Profile for simple CMC requests')),
-    cfg.StrOpt('auto_approved_profiles',
-               default="caServerCert",
-               help=u._('List of automatically approved enrollment profiles')),
-    cfg.StrOpt('ca_expiration_time',
-               default=cm.CA_INFO_DEFAULT_EXPIRATION_DAYS,
-               help=u._('Time in days for CA entries to expire')),
-    cfg.StrOpt('plugin_working_dir',
-               help=u._('Working directory for Dogtag plugin'))
-]
-
-CONF.register_group(dogtag_plugin_group)
-CONF.register_opts(dogtag_plugin_opts, group=dogtag_plugin_group)
-config.parse_args(CONF)
-
 CERT_HEADER = "-----BEGIN CERTIFICATE-----"
 CERT_FOOTER = "-----END CERTIFICATE-----"
 
@@ -97,8 +69,8 @@ def _create_nss_db_if_needed(nss_db_path, nss_password):
             nss_db_path, nss_password, over_write=True)
         return True
     else:
-        LOG.info(u._LI("The nss_db_path provided already exists, so the "
-                       "database is assumed to be already set up."))
+        LOG.info("The nss_db_path provided already exists, so the "
+                 "database is assumed to be already set up.")
         return False
 
 
@@ -115,8 +87,8 @@ def _setup_nss_db_services(conf):
     nss_db_path, nss_password = (conf.dogtag_plugin.nss_db_path,
                                  conf.dogtag_plugin.nss_password)
     if nss_db_path is None:
-        LOG.warning(u._LW("nss_db_path was not provided so the crypto "
-                          "provider functions were not initialized."))
+        LOG.warning("nss_db_path was not provided so the crypto "
+                    "provider functions were not initialized.")
         return None
     if nss_password is None:
         raise ValueError(u._("nss_password is required"))
@@ -139,7 +111,7 @@ def _import_kra_transport_cert_to_nss_db(conf, crypto):
         crypto.import_cert(KRA_TRANSPORT_NICK, transport_cert, "u,u,u")
     except Exception as e:
         LOG.error("Error in importing transport cert."
-                  " KRA may not be enabled: " + str(e))
+                  " KRA may not be enabled: %s", e)
 
 
 def create_connection(conf, subsystem_path):
@@ -155,7 +127,8 @@ def create_connection(conf, subsystem_path):
     return connection
 
 crypto = _setup_nss_db_services(CONF)
-crypto.initialize()
+if crypto:
+    crypto.initialize()
 
 
 class DogtagPluginAlgorithmException(exception.BarbicanException):
@@ -202,9 +175,13 @@ class DogtagKRAPlugin(sstore.SecretStoreBase):
         self.keyclient = kraclient.keys
 
         self.keyclient.set_transport_cert(KRA_TRANSPORT_NICK)
+        self.plugin_name = conf.dogtag_plugin.plugin_name
 
         LOG.debug("completed DogtagKRAPlugin init")
 
+    def get_plugin_name(self):
+        return self.plugin_name
+
     def store_secret(self, secret_dto):
         """Store a secret in the KRA
 
@@ -225,7 +202,7 @@ class DogtagKRAPlugin(sstore.SecretStoreBase):
         the key_id
         """
         data_type = key.KeyClient.PASS_PHRASE_TYPE
-        client_key_id = uuid.uuid4().hex
+        client_key_id = uuidutils.generate_uuid(dashed=False)
         if secret_dto.transport_key is not None:
             # TODO(alee-3) send the transport key with the archival request
             # once the Dogtag Client API changes.
@@ -403,7 +380,7 @@ class DogtagKRAPlugin(sstore.SecretStoreBase):
         usages = [key.SymKeyGenerationRequest.DECRYPT_USAGE,
                   key.SymKeyGenerationRequest.ENCRYPT_USAGE]
 
-        client_key_id = uuid.uuid4().hex
+        client_key_id = uuidutils.generate_uuid()
         algorithm = self._map_algorithm(key_spec.alg.lower())
 
         if algorithm is None:
@@ -443,7 +420,7 @@ class DogtagKRAPlugin(sstore.SecretStoreBase):
         usages = [key.AsymKeyGenerationRequest.DECRYPT_USAGE,
                   key.AsymKeyGenerationRequest.ENCRYPT_USAGE]
 
-        client_key_id = uuid.uuid4().hex
+        client_key_id = uuidutils.generate_uuid()
         algorithm = self._map_algorithm(key_spec.alg.lower())
         passphrase = key_spec.passphrase
 
@@ -460,7 +437,7 @@ class DogtagKRAPlugin(sstore.SecretStoreBase):
                 )
 
             stored_passphrase_info = self.keyclient.archive_key(
-                uuid.uuid4().hex,
+                uuidutils.generate_uuid(),
                 self.keyclient.PASS_PHRASE_TYPE,
                 base64.b64encode(passphrase))
 
@@ -663,7 +640,7 @@ def _catch_subca_deletion_exceptions(ca_related_function):
         try:
             return ca_related_function(self, *args, **kwargs)
         except pki.ResourceNotFoundException as e:
-            LOG.warning(u._LI("Sub-CA already deleted"))
+            LOG.warning("Sub-CA already deleted")
             pass
         except pki.PKIException as e:
             raise exception.SubCADeletionErrors(reason=e.message)
@@ -722,7 +699,7 @@ class DogtagCAPlugin(cm.CertificatePluginBase):
                         "%Y-%m-%d %H:%M:%S.%f"
                     )
             except (ValueError, TypeError):
-                LOG.warning(u._LI("Invalid data read from expiration file"))
+                LOG.warning("Invalid data read from expiration file")
                 self.expiration = datetime.utcnow()
         return self._expiration
 
@@ -761,15 +738,15 @@ class DogtagCAPlugin(cm.CertificatePluginBase):
                 feature_client = feature.FeatureClient(connection)
                 authority_feature = feature_client.get_feature("authority")
                 if authority_feature.enabled:
-                    LOG.info(u._LI("Sub-CAs are enabled by Dogtag server"))
+                    LOG.info("Sub-CAs are enabled by Dogtag server")
                     return True
                 else:
-                    LOG.info(u._LI("Sub-CAs are not enabled by Dogtag server"))
+                    LOG.info("Sub-CAs are not enabled by Dogtag server")
             except (request_exceptions.HTTPError,
                     pki.ResourceNotFoundException):
-                LOG.info(u._LI("Sub-CAs are not supported by Dogtag server"))
+                LOG.info("Sub-CAs are not supported by Dogtag server")
         else:
-            LOG.info(u._LI("Sub-CAs are not supported by Dogtag client"))
+            LOG.info("Sub-CAs are not supported by Dogtag client")
         return False
 
     def _get_request_id(self, order_id, plugin_meta, operation):
