@@ -19,6 +19,7 @@ An implementation of the SecretStore that uses the KMIP backend.
 
 import base64
 import os
+import ssl
 import stat
 
 from cryptography.hazmat.backends import default_backend
@@ -33,6 +34,7 @@ from oslo_config import cfg
 from oslo_log import log
 
 from barbican.common import config
+from barbican.common import exception
 from barbican import i18n as u  # noqa
 from barbican.plugin.interface import secret_store as ss
 from barbican.plugin.util import translations
@@ -54,12 +56,12 @@ kmip_opts = [
                default='localhost',
                help=u._('Address of the KMIP server')
                ),
-    cfg.StrOpt('port',
-               default='5696',
+    cfg.IntOpt('port',
+               default=5696,
                help=u._('Port for the KMIP server'),
                ),
     cfg.StrOpt('ssl_version',
-               default='PROTOCOL_TLSv1',
+               default='PROTOCOL_TLSv1_2',
                help=u._('SSL version, maps to the module ssl\'s constants'),
                ),
     cfg.StrOpt('ca_certs',
@@ -75,12 +77,20 @@ kmip_opts = [
     cfg.BoolOpt('pkcs1_only',
                 default=False,
                 help=u._('Only support PKCS#1 encoding of asymmetric keys'),
-                )
+                ),
+    cfg.StrOpt('plugin_name',
+               help=u._('User friendly plugin name'),
+               default='KMIP HSM'),
 ]
 CONF.register_group(kmip_opt_group)
 CONF.register_opts(kmip_opts, group=kmip_opt_group)
 config.parse_args(CONF)
 
+
+def list_opts():
+    yield kmip_opt_group, kmip_opts
+
+
 attribute_debug_msg = "Created attribute type %s with value %s"
 
 
@@ -88,11 +98,11 @@ def convert_pem_to_der(pem_pkcs1):
     # cryptography adds an extra '\n' to end of PEM file
     # added if statement so if future version removes extra \n tests will not
     # break
-    if pem_pkcs1.endswith('\n'):
+    if pem_pkcs1.endswith(b'\n'):
         pem_pkcs1 = pem_pkcs1[:-1]
     # neither PyCrypto or cryptography support export in DER format with PKCS1
     # encoding so doing by hand
-    der_pkcs1_b64 = ''.join(pem_pkcs1.split('\n')[1:-1])
+    der_pkcs1_b64 = b''.join(pem_pkcs1.split(b'\n')[1:-1])
     der_pkcs1 = base64.b64decode(der_pkcs1_b64)
     return der_pkcs1
 
@@ -121,9 +131,20 @@ def get_private_key_der_pkcs1(pem):
     return convert_pem_to_der(pem_pkcs1)
 
 
-class KMIPSecretStoreError(Exception):
-    def __init__(self, what):
-        super(KMIPSecretStoreError, self).__init__(what)
+class KMIPSecretStoreError(exception.BarbicanException):
+    def __init__(self, message):
+        super(KMIPSecretStoreError, self).__init__(message)
+
+
+class KMIPSecretStoreActionNotSupported(exception.BarbicanHTTPException):
+    """Raised if no plugins are found that support the requested operation."""
+
+    client_message = u._("KMIP plugin action not support.")
+    status_code = 400
+
+    def __init__(self, message):
+        self.message = message
+        super(KMIPSecretStoreActionNotSupported, self).__init__()
 
 
 class KMIPSecretStore(ss.SecretStoreBase):
@@ -204,6 +225,8 @@ class KMIPSecretStore(ss.SecretStoreBase):
             enums.CryptographicAlgorithm.RSA: ss.KeyAlgorithm.RSA
         }
 
+        self.plugin_name = conf.kmip_plugin.plugin_name
+
         if conf.kmip_plugin.keyfile is not None:
             self._validate_keyfile_permissions(conf.kmip_plugin.keyfile)
 
@@ -220,6 +243,11 @@ class KMIPSecretStore(ss.SecretStoreBase):
                     credential_value))
 
         config = conf.kmip_plugin
+
+        if not getattr(ssl, config.ssl_version, None):
+            LOG.error("The configured SSL version (%s) is not available"
+                      " on the system.", config.ssl_version)
+
         self.client = client.ProxyKmipClient(
             hostname=config.host,
             port=config.port,
@@ -230,6 +258,9 @@ class KMIPSecretStore(ss.SecretStoreBase):
             username=config.username,
             password=config.password)
 
+    def get_plugin_name(self):
+        return self.plugin_name
+
     def generate_symmetric_key(self, key_spec):
         """Generate a symmetric key.
 
@@ -254,15 +285,15 @@ class KMIPSecretStore(ss.SecretStoreBase):
         algorithm = self._get_kmip_algorithm(key_spec.alg.lower())
         try:
             with self.client:
-                LOG.debug("Opened connection to KMIP client for secret " +
+                LOG.debug("Opened connection to KMIP client for secret "
                           "generation")
                 uuid = self.client.create(algorithm, key_spec.bit_length)
                 LOG.debug("SUCCESS: Symmetric key generated with "
                           "uuid: %s", uuid)
                 return {KMIPSecretStore.KEY_UUID: uuid}
         except Exception as e:
-            LOG.exception(u._LE("Error opening or writing to client"))
-            raise ss.SecretGeneralException(str(e))
+            LOG.exception("Error opening or writing to client")
+            raise ss.SecretGeneralException(e)
 
     def generate_asymmetric_key(self, key_spec):
         """Generate an asymmetric key pair.
@@ -274,6 +305,7 @@ class KMIPSecretStore(ss.SecretStoreBase):
         :param key_spec: KeySpec with asymmetric algorithm and bit_length
         :returns: AsymmetricKeyMetadataDTO with the key UUIDs
         :raises: SecretGeneralException, SecretAlgorithmNotSupportedException
+                 KMIPSecretStoreActionNotSupported
         """
         LOG.debug("Starting asymmetric key generation with KMIP plugin")
         if not self.generate_supports(key_spec):
@@ -281,13 +313,10 @@ class KMIPSecretStore(ss.SecretStoreBase):
                 key_spec.alg)
 
         if key_spec.alg.lower() not in ss.KeyAlgorithm.ASYMMETRIC_ALGORITHMS:
-            raise KMIPSecretStoreError(
-                u._("An unsupported algorithm {algorithm} was passed to "
-                    "the 'generate_asymmetric_key' method").format(
-                        algorithm=key_spec.alg))
+            raise ss.SecretAlgorithmNotSupportedException(key_spec.alg)
 
         if key_spec.passphrase:
-            raise KMIPSecretStoreError(
+            raise KMIPSecretStoreActionNotSupported(
                 u._('KMIP plugin does not currently support protecting the '
                     'private key with a passphrase'))
 
@@ -296,13 +325,15 @@ class KMIPSecretStore(ss.SecretStoreBase):
 
         try:
             with self.client:
-                LOG.debug("Opened connection to KMIP client for asymmetric " +
-                          "secret generation")
+                LOG.debug("Opened connection to KMIP client for "
+                          "asymmetric secret generation")
                 public_uuid, private_uuid = self.client.create_key_pair(
                     algorithm, length)
                 LOG.debug("SUCCESS: Asymmetric key pair generated with "
-                          "public key uuid: %s and private key uuid: %s",
-                          public_uuid, private_uuid)
+                          "public key uuid: %(public_uuid)s and "
+                          "private key uuid: %(private_uuid)s" %
+                          {'public_uuid': public_uuid,
+                           'private_uuid': private_uuid})
                 private_key_metadata = {KMIPSecretStore.KEY_UUID: private_uuid}
                 public_key_metadata = {KMIPSecretStore.KEY_UUID: public_uuid}
                 passphrase_metadata = None
@@ -310,8 +341,8 @@ class KMIPSecretStore(ss.SecretStoreBase):
                                                    public_key_metadata,
                                                    passphrase_metadata)
         except Exception as e:
-            LOG.exception(u._LE("Error opening or writing to client"))
-            raise ss.SecretGeneralException(str(e))
+            LOG.exception("Error opening or writing to client")
+            raise ss.SecretGeneralException(e)
 
     def store_secret(self, secret_dto):
         """Stores a secret
@@ -344,8 +375,8 @@ class KMIPSecretStore(ss.SecretStoreBase):
                 LOG.debug("SUCCESS: Key stored with uuid: %s", uuid)
                 return {KMIPSecretStore.KEY_UUID: uuid}
         except Exception as e:
-            LOG.exception(u._LE("Error opening or writing to client"))
-            raise ss.SecretGeneralException(str(e))
+            LOG.exception("Error opening or writing to client")
+            raise ss.SecretGeneralException(e)
 
     def get_secret(self, secret_type, secret_metadata):
         """Gets a secret
@@ -360,13 +391,13 @@ class KMIPSecretStore(ss.SecretStoreBase):
         uuid = str(secret_metadata[KMIPSecretStore.KEY_UUID])
         try:
             with self.client:
-                LOG.debug("Opened connection to KMIP client for secret " +
+                LOG.debug("Opened connection to KMIP client for secret "
                           "retrieval")
                 managed_object = self.client.get(uuid)
                 return self._get_barbican_secret(managed_object, secret_type)
         except Exception as e:
-            LOG.exception(u._LE("Error opening or writing to client"))
-            raise ss.SecretGeneralException(str(e))
+            LOG.exception("Error opening or writing to client")
+            raise ss.SecretGeneralException(e)
 
     def generate_supports(self, key_spec):
         """Key generation supported?
@@ -404,8 +435,8 @@ class KMIPSecretStore(ss.SecretStoreBase):
                 LOG.debug("Opened connection to KMIP client")
                 self.client.destroy(uuid)
         except Exception as e:
-            LOG.exception(u._LE("Error opening or writing to client"))
-            raise ss.SecretGeneralException(str(e))
+            LOG.exception("Error opening or writing to client")
+            raise ss.SecretGeneralException(e)
 
     def store_secret_supports(self, key_spec):
         """Key storage supported?
@@ -502,8 +533,7 @@ class KMIPSecretStore(ss.SecretStoreBase):
     def _map_type_ss_to_kmip(self, object_type):
         """Map SecretType to KMIP type enum
 
-        Returns None if the type is not supported. The KMIP plugin only
-        supports symmetric and asymmetric keys for now.
+        Returns None if the type is not supported.
         :param object_type: SecretType enum value
         :returns: KMIP type enums if supported, None if not supported
         """
@@ -537,7 +567,7 @@ class KMIPSecretStore(ss.SecretStoreBase):
             reason=result.result_reason,
             message=result.result_message
         )
-        LOG.error(u._LE("ERROR from KMIP server: %s"), msg)
+        LOG.error("ERROR from KMIP server: %s", msg)
         raise ss.SecretGeneralException(msg)
 
     def _validate_keyfile_permissions(self, path):
@@ -545,7 +575,7 @@ class KMIPSecretStore(ss.SecretStoreBase):
 
         Key files are extremely sensitive, they should be owned by the user
         who they relate to. They should be readable only (to avoid accidental
-        changes). They should not be readable or writeable by any other user.
+        changes). They should not be readable or writable by any other user.
 
         :raises: KMIPSecretStoreError
         """
