@@ -62,7 +62,7 @@ def get_public_key_req():
 
 def get_certificate_req():
     return {'name': 'mycertificate',
-            'payload_content_type': 'application/pkix-cert',
+            'payload_content_type': 'application/octet-stream',
             'payload_content_encoding': 'base64',
             'algorithm': 'rsa',
             'bit_length': 2048,
@@ -583,8 +583,7 @@ class WhenTestingContainerValidator(utils.BaseTestCase):
     def setUp(self):
         super(WhenTestingContainerValidator, self).setUp()
 
-        validators.CONF.set_override("host_href", "http://localhost:9311",
-                                     enforce_type=True)
+        validators.CONF.set_override("host_href", "http://localhost:9311")
 
         self.name = 'name'
         self.type = 'generic'
@@ -857,8 +856,7 @@ class WhenTestingRSAContainerValidator(utils.BaseTestCase):
     def setUp(self):
         super(WhenTestingRSAContainerValidator, self).setUp()
 
-        validators.CONF.set_override("host_href", "http://localhost:9311",
-                                     enforce_type=True)
+        validators.CONF.set_override("host_href", "http://localhost:9311")
 
         self.name = 'name'
         self.type = 'rsa'
@@ -973,8 +971,7 @@ class WhenTestingCertificateContainerValidator(utils.BaseTestCase):
     def setUp(self):
         super(WhenTestingCertificateContainerValidator, self).setUp()
 
-        validators.CONF.set_override("host_href", "http://localhost:9311",
-                                     enforce_type=True)
+        validators.CONF.set_override("host_href", "http://localhost:9311")
 
         self.name = 'name'
         self.type = 'certificate'
