@@ -144,17 +144,6 @@ class WhenInvokingExceptionMethods(utils.BaseTestCase):
             "No entities of type test_entity found",
             exception_result.message)
 
-    def test_should_raise_for_entity_already_exists(self):
-
-        exception_result = self.assertRaises(
-            exception.Duplicate,
-            repositories._raise_entity_already_exists,
-            self.entity_name)
-
-        self.assertEqual(
-            "Entity 'test_entity' already exists",
-            exception_result.message)
-
 
 class WhenTestingBaseRepository(database_utils.RepositoryTestCase):
 
@@ -210,10 +199,8 @@ class WhenTestingWrapDbError(utils.BaseTestCase):
 
     def setUp(self):
         super(WhenTestingWrapDbError, self).setUp()
-        repositories.CONF.set_override("sql_max_retries", 0,
-                                       enforce_type=True)
-        repositories.CONF.set_override("sql_retry_interval", 0,
-                                       enforce_type=True)
+        repositories.CONF.set_override("sql_max_retries", 0)
+        repositories.CONF.set_override("sql_retry_interval", 0)
 
     @mock.patch('barbican.model.repositories.is_db_connection_error')
     def test_should_raise_operational_error_is_connection_error(
@@ -235,8 +222,7 @@ class WhenTestingGetEnginePrivate(utils.BaseTestCase):
     def setUp(self):
         super(WhenTestingGetEnginePrivate, self).setUp()
 
-        repositories.CONF.set_override("sql_connection", "connection",
-                                       enforce_type=True)
+        repositories.CONF.set_override("sql_connection", "connection")
 
     @mock.patch('barbican.model.repositories._create_engine')
     def test_should_raise_value_exception_engine_create_failure(
@@ -259,8 +245,7 @@ class WhenTestingGetEnginePrivate(utils.BaseTestCase):
     def test_should_complete_with_no_alembic_create_default_configs(
             self, mock_create_engine):
 
-        repositories.CONF.set_override("db_auto_create", False,
-                                       enforce_type=True)
+        repositories.CONF.set_override("db_auto_create", False)
         engine = mock.MagicMock()
         mock_create_engine.return_value = engine
 
@@ -270,23 +255,20 @@ class WhenTestingGetEnginePrivate(utils.BaseTestCase):
         engine.connect.assert_called_once_with()
         mock_create_engine.assert_called_once_with(
             'connection',
-            pool_recycle=3600,
-            convert_unicode=True,
-            echo=False
+            idle_timeout=3600,
+            max_pool_size=repositories.CONF.sql_pool_size,
+            max_overflow=repositories.CONF.sql_pool_max_overflow
         )
 
     @mock.patch('barbican.model.repositories._create_engine')
     def test_should_complete_with_no_alembic_create_pool_configs(
             self, mock_create_engine):
 
-        repositories.CONF.set_override("db_auto_create", False,
-                                       enforce_type=True)
+        repositories.CONF.set_override("db_auto_create", False)
         repositories.CONF.set_override(
-            "sql_pool_class", "QueuePool", enforce_type=True)
-        repositories.CONF.set_override("sql_pool_size", 22,
-                                       enforce_type=True)
-        repositories.CONF.set_override("sql_pool_max_overflow", 11,
-                                       enforce_type=True)
+            "sql_pool_class", "QueuePool")
+        repositories.CONF.set_override("sql_pool_size", 22)
+        repositories.CONF.set_override("sql_pool_max_overflow", 11)
 
         engine = mock.MagicMock()
         mock_create_engine.return_value = engine
@@ -297,11 +279,8 @@ class WhenTestingGetEnginePrivate(utils.BaseTestCase):
         engine.connect.assert_called_once_with()
         mock_create_engine.assert_called_once_with(
             'connection',
-            pool_recycle=3600,
-            convert_unicode=True,
-            echo=False,
-            poolclass=sqlalchemy.pool.QueuePool,
-            pool_size=22,
+            idle_timeout=3600,
+            max_pool_size=22,
             max_overflow=11
         )
 
@@ -347,8 +326,7 @@ class WhenTestingMigrations(utils.BaseTestCase):
 
     def setUp(self):
         super(WhenTestingMigrations, self).setUp()
-        repositories.CONF.set_override("sql_connection", "connection",
-                                       enforce_type=True)
+        repositories.CONF.set_override("sql_connection", "connection")
         self.alembic_config = migration.init_config()
         self.alembic_config.barbican_config = cfg.CONF
 
