@@ -55,7 +55,7 @@ class WhenTestingContainerConsumerRepository(utils.RepositoryTestCase):
             container.id, project.external_id, session=session)
         self.assertEqual(1, len(container2.consumers))
 
-    def test_should_raise_duplicate_create_same_composite_key_no_id(self):
+    def test_should_raise_constraint_create_same_composite_key_no_id(self):
         session = self.repo.get_session()
 
         project = models.Project()
@@ -82,12 +82,12 @@ class WhenTestingContainerConsumerRepository(utils.RepositoryTestCase):
             container.id, project.id, {'name': 'name', 'URL': 'www.foo.com'})
 
         exception_result = self.assertRaises(
-            exception.Duplicate,
+            exception.ConstraintCheck,
             self.repo.create_from,
             consumer2,
             session=session)
-        self.assertEqual(
-            "Entity 'ContainerConsumer' already exists",
+        self.assertIn(
+            "SQL constraint check failed",
             exception_result.message)
 
     def test_should_raise_no_result_found_get_container_id(self):
@@ -136,7 +136,7 @@ class WhenTestingContainerConsumerRepository(utils.RepositoryTestCase):
         session.commit()
         count = self.repo.get_count(project.id, session=session)
 
-        self.assertEqual(count, 0)
+        self.assertEqual(0, count)
 
     def test_should_get_count_one(self):
         session = self.repo.get_session()
@@ -155,7 +155,7 @@ class WhenTestingContainerConsumerRepository(utils.RepositoryTestCase):
         session.commit()
 
         count = self.repo.get_count(project.id, session=session)
-        self.assertEqual(count, 1)
+        self.assertEqual(1, count)
 
     def test_should_get_count_one_after_delete(self):
         session = self.repo.get_session()
@@ -178,11 +178,11 @@ class WhenTestingContainerConsumerRepository(utils.RepositoryTestCase):
         session.commit()
 
         count = self.repo.get_count(project.id, session=session)
-        self.assertEqual(count, 2)
+        self.assertEqual(2, count)
 
         self.repo.delete_entity_by_id(consumer.id, "my keystone id",
                                       session=session)
         session.commit()
 
         count = self.repo.get_count(project.id, session=session)
-        self.assertEqual(count, 1)
+        self.assertEqual(1, count)
