@@ -9,7 +9,7 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-import uuid
+from oslo_utils import uuidutils
 
 from barbican.common import exception
 from barbican.model import models
@@ -137,24 +137,24 @@ class WhenTestingSecretStoresRepo(database_utils.RepositoryTestCase):
         self.assertEqual("middle_name", all_stores[3].name)
         self.assertEqual(False, all_stores[3].global_default)
 
-    def test_should_raise_duplicate_for_same_plugin_names(self):
+    def test_should_raise_constraint_for_same_plugin_names(self):
         """Check for store and crypto plugin name combination uniqueness"""
 
         name = 'second_name'
         store_plugin = 'second_store'
         crypto_plugin = 'second_crypto'
         self._create_secret_store(name, store_plugin, crypto_plugin, False)
-        self.assertRaises(exception.Duplicate, self._create_secret_store,
+        self.assertRaises(exception.ConstraintCheck, self._create_secret_store,
                           "thrid_name", store_plugin, crypto_plugin, False)
 
-    def test_should_raise_duplicate_for_same_names(self):
+    def test_should_raise_constraint_for_same_names(self):
         """Check for secret store 'name' uniqueness"""
 
         name = 'Db backend'
         store_plugin = 'second_store'
         crypto_plugin = 'second_crypto'
         self._create_secret_store(name, store_plugin, crypto_plugin, False)
-        self.assertRaises(exception.Duplicate, self._create_secret_store,
+        self.assertRaises(exception.ConstraintCheck, self._create_secret_store,
                           name, "another_store", "another_crypto", False)
 
     def test_do_entity_name(self):
@@ -169,8 +169,8 @@ class WhenTestingSecretStoresRepo(database_utils.RepositoryTestCase):
         try:
             self._create_secret_store(name, store_plugin, crypto_plugin, False)
             self.assertFail()
-        except exception.Duplicate as ex:
-            self.assertIn("SecretStores", ex.message)
+        except exception.ConstraintCheck as ex:
+            self.assertIn("SQL constraint check failed", ex.message)
 
 
 class WhenTestingProjectSecretStoreRepo(database_utils.RepositoryTestCase):
@@ -205,7 +205,8 @@ class WhenTestingProjectSecretStoreRepo(database_utils.RepositoryTestCase):
         session = self.proj_store_repo.get_session()
 
         project = models.Project()
-        project.external_id = "keystone_project_id" + uuid.uuid4().hex
+        project.external_id = ("keystone_project_id" +
+                               uuidutils.generate_uuid(dashed=False))
         project.save(session=session)
         return project
 
@@ -264,7 +265,7 @@ class WhenTestingProjectSecretStoreRepo(database_utils.RepositoryTestCase):
 
         self.assertIsNone(proj_s_store)
 
-    def test_should_raise_duplicate_for_same_project_id(self):
+    def test_should_raise_constraint_for_same_project_id(self):
         """Check preferred secret store is set only once for project"""
 
         project1 = self._create_project()
@@ -284,7 +285,8 @@ class WhenTestingProjectSecretStoreRepo(database_utils.RepositoryTestCase):
         s_store2 = self._create_secret_store(name, store_plugin,
                                              crypto_plugin, False)
 
-        self.assertRaises(exception.Duplicate, self._create_project_store,
+        self.assertRaises(exception.ConstraintCheck,
+                          self._create_project_store,
                           project1.id, s_store2.id)
 
     def test_do_entity_name(self):
@@ -311,8 +313,8 @@ class WhenTestingProjectSecretStoreRepo(database_utils.RepositoryTestCase):
                                                  crypto_plugin, False)
             self._create_project_store(project1.id, s_store2.id)
             self.assertFail()
-        except exception.Duplicate as ex:
-            self.assertIn("ProjectSecretStore", ex.message)
+        except exception.ConstraintCheck as ex:
+            self.assertIn("SQL constraint check failed", ex.message)
 
     def test_get_secret_store_for_project(self):
         project1 = self._create_project()
@@ -358,7 +360,8 @@ class WhenTestingProjectSecretStoreRepo(database_utils.RepositoryTestCase):
         self.assertIsNone(returned_value)
 
     def test_get_project_entities(self):
-        entities = self.proj_store_repo.get_project_entities(uuid.uuid4().hex)
+        entities = self.proj_store_repo.get_project_entities(
+            uuidutils.generate_uuid(dashed=False))
         self.assertEqual([], entities)
 
     def test_create_or_update_for_project(self):
