@@ -36,7 +36,7 @@ class WhenCreatingNewSecret(utils.BaseTestCase):
         self.parsed_order = {'secret': self.parsed_secret}
 
     def test_new_secret_is_created_from_dict(self):
-        date_time = datetime.datetime.now().isoformat()
+        date_time = datetime.datetime.utcnow().isoformat()
         self.parsed_secret['expiration'] = date_time
         secret = models.Secret(self.parsed_secret)
         self.assertEqual(self.parsed_secret['name'], secret.name)
@@ -57,7 +57,7 @@ class WhenCreatingNewSecret(utils.BaseTestCase):
 
     def test_new_secret_is_created_with_default_secret_type(self):
         secret_spec = dict(self.parsed_secret)
-        date_time = datetime.datetime.now().isoformat()
+        date_time = datetime.datetime.utcnow().isoformat()
         secret_spec['expiration'] = date_time
         del secret_spec['secret_type']
         secret = models.Secret(secret_spec)
@@ -654,7 +654,7 @@ class WhenCreatingNewSecretStores(utils.BaseTestCase):
         self.assertEqual(store_plugin, ss.store_plugin)
         self.assertEqual(crypto_plugin, ss.crypto_plugin)
         self.assertEqual(name, ss.name)
-        self.assertEqual(True, ss.global_default)
+        self.assertTrue(ss.global_default)
         self.assertEqual(models.States.ACTIVE, ss.status)
 
     def test_new_secret_stores_required_input_only(self):
@@ -692,8 +692,7 @@ class WhenCreatingNewSecretStores(utils.BaseTestCase):
                          ss.to_dict_fields()['store_plugin'])
         self.assertEqual(crypto_plugin,
                          ss.to_dict_fields()['crypto_plugin'])
-        self.assertEqual(True,
-                         ss.to_dict_fields()['global_default'])
+        self.assertTrue(ss.to_dict_fields()['global_default'])
         self.assertEqual(models.States.ACTIVE,
                          ss.to_dict_fields()['status'])
         self.assertEqual(name, ss.to_dict_fields()['name'])
