@@ -14,7 +14,4 @@
 
 set -ex
 
-# Install barbican devstack integration
-export DEVSTACK_LOCAL_CONFIG="enable_plugin barbican https://git.openstack.org/openstack/barbican"
-
 $BASE/new/devstack-gate/devstack-vm-gate.sh
