@@ -71,7 +71,7 @@ create_container_rsa_data = {
 accepted_str_values = {
     'alphanumeric': ['a2j3j6ll9'],
     'punctuation': ['~!@#$%^&*()_+`-={}[]|:;<>,.?'],
-    'len_255': [str(bytearray().zfill(255))],
+    'len_255': [base.TestCase.max_sized_field],
     'uuid': ['54262d9d-4bc7-4821-8df0-dc2ca8e112bb'],
     'empty': ['']
 }
@@ -102,6 +102,10 @@ class BaseContainerTestCase(base.TestCase):
         self.behaviors.delete_all_created_containers()
         super(BaseContainerTestCase, self).tearDown()
 
+    def _cleanup_all_containers(self):
+        for user_name in self.client.get_all_functional_test_user_names():
+            self.behaviors.delete_all_containers_for_user(user_name=user_name)
+
     def _create_a_secret(self):
         secret_defaults_data = {
             "name": "AES key",
@@ -116,7 +120,7 @@ class BaseContainerTestCase(base.TestCase):
 
         secret_model = secret_models.SecretModel(**secret_defaults_data)
         resp, secret_ref = self.secret_behaviors.create_secret(secret_model)
-        self.assertEqual(resp.status_code, 201)
+        self.assertEqual(201, resp.status_code)
         self.assertIsNotNone(secret_ref)
 
         return secret_ref
@@ -132,7 +136,7 @@ class GenericContainersTestCase(BaseContainerTestCase):
         test_model.name = None
 
         resp, container_ref = self.behaviors.create_container(test_model)
-        self.assertEqual(resp.status_code, 201)
+        self.assertEqual(201, resp.status_code)
 
     @utils.parameterized_dataset({'0': [0], '1': [1], '50': [50]})
     @testcase.attr('positive')
@@ -147,7 +151,7 @@ class GenericContainersTestCase(BaseContainerTestCase):
             })
 
         resp, container_ref = self.behaviors.create_container(test_model)
-        self.assertEqual(resp.status_code, 201)
+        self.assertEqual(201, resp.status_code)
 
     @utils.parameterized_dataset(accepted_str_values)
     @testcase.attr('positive')
@@ -157,7 +161,7 @@ class GenericContainersTestCase(BaseContainerTestCase):
         test_model.name = name
 
         resp, container_ref = self.behaviors.create_container(test_model)
-        self.assertEqual(resp.status_code, 201)
+        self.assertEqual(201, resp.status_code)
 
     @utils.parameterized_dataset(accepted_str_values)
     @testcase.attr('positive')
@@ -170,10 +174,10 @@ class GenericContainersTestCase(BaseContainerTestCase):
         }]
 
         resp, container_ref = self.behaviors.create_container(test_model)
-        self.assertEqual(resp.status_code, 201)
+        self.assertEqual(201, resp.status_code)
 
         get_resp = self.behaviors.get_container(container_ref)
-        self.assertEqual(get_resp.status_code, 200)
+        self.assertEqual(200, get_resp.status_code)
         self.assertEqual(get_resp.model.secret_refs[0].name, name)
 
     @testcase.attr('negative')
@@ -183,7 +187,7 @@ class GenericContainersTestCase(BaseContainerTestCase):
         test_model.type = 'bad_type'
 
         resp, container_ref = self.behaviors.create_container(test_model)
-        self.assertEqual(resp.status_code, 400)
+        self.assertEqual(400, resp.status_code)
 
     @testcase.attr('negative')
     def test_create_defaults_duplicate_secret_refs(self):
@@ -194,22 +198,24 @@ class GenericContainersTestCase(BaseContainerTestCase):
         test_model.secret_refs[2]['secret_ref'] = self.secret_ref_1
 
         resp, container_ref = self.behaviors.create_container(test_model)
-        self.assertEqual(resp.status_code, 400)
+        self.assertEqual(400, resp.status_code)
 
     @testcase.attr('negative')
     def test_get_non_existent_container(self):
         """A get on a container that does not exist should return a 404."""
         resp = self.behaviors.get_container("not_a_ref")
-        self.assertEqual(resp.status_code, 404)
+        self.assertEqual(404, resp.status_code)
 
     @testcase.attr('negative')
     def test_delete_non_existent_container(self):
         """A delete on a container that does not exist should return a 404."""
         resp = self.behaviors.delete_container("not_a_ref", expected_fail=True)
-        self.assertEqual(resp.status_code, 404)
+        self.assertEqual(404, resp.status_code)
 
+    @testcase.skipIf(not base.conf_host_href_used, 'response href using '
+                     'wsgi request instead of CONF.host_href')
     @testcase.attr('positive')
-    def test_create_change_host_header(self, **kwargs):
+    def test_create_change_host_with_header_not_allowed(self, **kwargs):
         """Create a container with a (possibly) malicious host name header."""
 
         test_model = container_models.ContainerModel(**self.default_data)
@@ -220,13 +226,36 @@ class GenericContainersTestCase(BaseContainerTestCase):
         resp, container_ref = self.behaviors.create_container(
             test_model, extra_headers=changed_host_header)
 
-        self.assertEqual(resp.status_code, 201)
+        self.assertEqual(201, resp.status_code)
 
         # get Location field from result and assert that it is NOT the
         # malicious one.
         regex = '.*{0}.*'.format(malicious_hostname)
         self.assertNotRegexpMatches(resp.headers['location'], regex)
 
+    @testcase.skipIf(base.conf_host_href_used, 'response href using '
+                     'CONF.host_href instead of wsgi request')
+    @testcase.attr('positive')
+    def test_get_change_host_with_header_allowed(self, **kwargs):
+        """Get a container with a alternative proxy host name header."""
+
+        test_model = container_models.ContainerModel(**self.default_data)
+
+        another_proxy_hostname = 'proxy2.server.com'
+        changed_host_header = {'Host': another_proxy_hostname}
+
+        # In test, cannot pass different host header during create as returned
+        # container_href in response contains that host in url. That url is
+        # used in deleting that container during cleanup step.
+        resp, container_href = self.behaviors.create_container(test_model)
+        self.assertEqual(201, resp.status_code)
+
+        resp = self.behaviors.get_container(container_href,
+                                            extra_headers=changed_host_header)
+        # Assert that returned href has provided proxy hostname
+        regex = '.*{0}.*'.format(another_proxy_hostname)
+        self.assertRegexpMatches(resp.model.container_ref, regex)
+
 
 @utils.parameterized_test_case
 class RSAContainersTestCase(BaseContainerTestCase):
@@ -242,7 +271,7 @@ class RSAContainersTestCase(BaseContainerTestCase):
         test_model.secret_refs = [pub_key_ref, priv_key_ref]
 
         resp, container_ref = self.behaviors.create_container(test_model)
-        self.assertEqual(resp.status_code, 201)
+        self.assertEqual(201, resp.status_code)
 
     @utils.parameterized_dataset(accepted_str_values)
     @testcase.attr('positive')
@@ -252,7 +281,7 @@ class RSAContainersTestCase(BaseContainerTestCase):
         test_model.name = name
 
         resp, container_ref = self.behaviors.create_container(test_model)
-        self.assertEqual(resp.status_code, 201)
+        self.assertEqual(201, resp.status_code)
 
     @testcase.attr('negative')
     def test_create_rsa_invalid_key_names(self):
@@ -274,7 +303,7 @@ class RSAContainersTestCase(BaseContainerTestCase):
         ]
 
         resp, container_ref = self.behaviors.create_container(test_model)
-        self.assertEqual(resp.status_code, 400)
+        self.assertEqual(400, resp.status_code)
 
     @testcase.attr('negative')
     def test_create_rsa_no_public_key(self):
@@ -286,7 +315,7 @@ class RSAContainersTestCase(BaseContainerTestCase):
         test_model.secret_refs[0]['name'] = 'secret_1'
 
         resp, container_ref = self.behaviors.create_container(test_model)
-        self.assertEqual(resp.status_code, 400)
+        self.assertEqual(400, resp.status_code)
 
     @testcase.attr('negative')
     def test_create_rsa_no_private_key(self):
@@ -298,10 +327,12 @@ class RSAContainersTestCase(BaseContainerTestCase):
         test_model.secret_refs[1]['name'] = 'secret_1'
 
         resp, container_ref = self.behaviors.create_container(test_model)
-        self.assertEqual(resp.status_code, 400)
+        self.assertEqual(400, resp.status_code)
 
+    @testcase.skipIf(not base.conf_host_href_used, 'response href using '
+                     'wsgi request instead of CONF.host_href')
     @testcase.attr('positive')
-    def test_create_rsa_change_host_header(self, **kwargs):
+    def test_create_rsa_change_host_with_header_not_allowed(self, **kwargs):
         """Create a container with a (possibly) malicious host name header."""
 
         test_model = container_models.ContainerModel(**self.default_data)
@@ -312,13 +343,36 @@ class RSAContainersTestCase(BaseContainerTestCase):
         resp, container_ref = self.behaviors.create_container(
             test_model, extra_headers=changed_host_header)
 
-        self.assertEqual(resp.status_code, 201)
+        self.assertEqual(201, resp.status_code)
 
         # get Location field from result and assert that it is NOT the
         # malicious one.
         regex = '.*{0}.*'.format(malicious_hostname)
         self.assertNotRegexpMatches(resp.headers['location'], regex)
 
+    @testcase.skipIf(base.conf_host_href_used, 'response href using '
+                     'CONF.host_href instead of wsgi request')
+    @testcase.attr('positive')
+    def test_get_rsa_change_host_with_header_allowed(self, **kwargs):
+        """Get a container with a alternative proxy host name header."""
+
+        test_model = container_models.ContainerModel(**self.default_data)
+
+        another_proxy_hostname = 'proxy2.server.com'
+        changed_host_header = {'Host': another_proxy_hostname}
+
+        # In test, cannot pass different host header during create as returned
+        # container_href in response contains that host in url. That url is
+        # used in deleting that container during cleanup step.
+        resp, container_href = self.behaviors.create_container(test_model)
+        self.assertEqual(201, resp.status_code)
+
+        resp = self.behaviors.get_container(container_href,
+                                            extra_headers=changed_host_header)
+        # Assert that returned href has provided proxy hostname
+        regex = '.*{0}.*'.format(another_proxy_hostname)
+        self.assertRegexpMatches(resp.model.container_ref, regex)
+
 
 class ContainersPagingTestCase(base.PagingTestCase):
 
@@ -346,12 +400,13 @@ class ContainersPagingTestCase(base.PagingTestCase):
 
         secret_model = secret_models.SecretModel(**secret_defaults_data)
         resp, secret_ref = self.secret_behaviors.create_secret(secret_model)
-        self.assertEqual(resp.status_code, 201)
+        self.assertEqual(201, resp.status_code)
         self.assertIsNotNone(secret_ref)
 
         return secret_ref
 
     def tearDown(self):
+        self.secret_behaviors.delete_all_created_secrets()
         self.behaviors.delete_all_created_containers()
         super(ContainersPagingTestCase, self).tearDown()
 
